@@ -170,7 +170,7 @@
   return(state)
 }
 
-#' Download BOM XML Files and Load into Session
+#' Import BOM XML Files from Server Into R Session
 #'
 #' @param xml_url URL of XML file to be downloaded/parsed/loaded.
 #'
@@ -180,9 +180,7 @@
 #' @noRd
 .get_xml <- function(xml_url) {
   tryCatch({
-    xml <- curl::curl(xml_url, open = "rb")
-    on.exit(close(xml))
-    xml_object <- xml2::read_xml(xml)
+    xml_object <- xml2::read_xml(x = xml_url)
   },
   error = function(x)
     stop(
