@@ -4,10 +4,10 @@
 #' @param latlon A length-2 numeric vector. By default, Canberra
 #' (approximately).
 #' @return A data frame of all weather stations (in this package) sorted
-#' by distance from \code{latlon}, ascending.
+#' by distance from \var{latlon}, ascending.
 #' @author Hugh Parsonage, \email{hugh.parsonage@@gmail.com}
 #' @importFrom data.table copy setorderv
-#' @export
+#' @export sweep_for_stations
 
 sweep_for_stations <- function(latlon = c(-35.3, 149.2)) {
   Lat <- latlon[1]
@@ -24,8 +24,9 @@ sweep_for_stations <- function(latlon = c(-35.3, 149.2)) {
   JSONurl_site_list %>%
     copy %>%
     # Lat Lon are in JSON
-    .[, "distance" := haversine_distance(Lat, Lon, lat, lon)] %>%
+    .[, "distance" := .haversine_distance(Lat, Lon, lat, lon)] %>%
     setorderv("distance") %>%
     .[] %>%
     as.data.frame
 }
+
