@@ -12,8 +12,11 @@ manage_cache <- NULL # nocov start
       x$cache_path_set(path = "bomrang", type = "user_cache_dir")
       manage_cache <<- x
     }
+    options(bomrang.connection = stdin())
   }
 
+"%||%" <- function(a, b) if (!is.null(a)) a else b
+
 # This function is never called.
 # It only supresses the "Namespaces in Imports field not imported from:" check
 # Suggested by @jeroen in rOpenSci Slack
@@ -21,6 +24,5 @@ manage_cache <- NULL # nocov start
 
 stub <- function(){
   rgdal::readGDAL()
-} # nocov end
-
-"%||%" <- function(a, b) if (!is.null(a)) a else b
+} 
+# nocov end
\ No newline at end of file
