@@ -12,22 +12,16 @@ test_that("Error handling", {
   expect_error(get_current_weather(latlon = 33), regexp = "[Ll]ength")
   expect_error(get_current_weather(latlon = c("-33", "151")),
                regexp = "[Nn]umeric")
-   # expect_error(get_current_weather("DOME A"),
-   #              regexp = "A station was matched.*not found at bom.gov.au.")
+  expect_error(get_current_weather("DOME A"),
+              regexp = "A station was matched.*not found at bom.gov.au.")
 })
 
 test_that("Query 'Melbourne Airport' returns data frame w/ correct station", {
-  YMML <- get_current_weather("Melbourne Airport", raw = TRUE)
-  expect_is(YMML, "data.frame")
+  YMML <- get_current_weather("Melbourne Airport")
+  expect_is(YMML, "bomrang_tbl")
   expect_equal(YMML$full_name[1], "Melbourne Airport")
 })
 
-test_that("Query of 'Melbourne Airport' returns time if cooked.", {
-  YMML <- get_current_weather("Melbourne Airport")
-  expect_is(YMML, "data.frame")
-  expect_equal(YMML$full_name[1], "Melbourne Airport")
-  expect_true("POSIXt" %in% class(YMML$aifstime_utc))
-})
 
 test_that("Query of 'Sydney' defaults to Observatory Hill", {
   expect_warning(get_current_weather("Sydney"),
@@ -56,8 +50,3 @@ test_that("Query c(-27, 149) returns Surat (QLD, b/n Roma and St George).", {
   Surat <- get_current_weather(latlon = c(-27, 149), emit_latlon_msg = FALSE)
   expect_equal(unique(Surat$full_name), "Surat")
 })
-
-test_that("Data table if requested", {
-  YMML <- get_current_weather("Melbourne Airport", as.data.table = TRUE)
-  expect_true("data.table" %in% class(YMML))
-})
