@@ -6,11 +6,11 @@ test_that("update_forecast_towns() stops if 'no'", {
   skip_on_cran()
   
   f <- file()
-  options(bomrang_connection = f)
+  options(bomrang.connection = f)
   ans <- "no"
   write(ans, f)
   expect_error(update_forecast_towns())
-  options(bomrang_connection = stdin())
+  options(bomrang.connection = stdin())
   close(f)
 })
 
@@ -18,7 +18,7 @@ test_that("update_forecast_towns() stops if 'no'", {
 test_that("update_forecast_towns() downloads and imports proper file", {
   skip_on_cran()
   f <- file()
-  options(bomrang_connection = f)
+  options(bomrang.connection = f)
   ans <- "yes"
   write(ans, f)
   update_forecast_towns()
